@@ -25,7 +25,6 @@ from unittest import mock
 from oslo_log import formatters
 from oslo_log import log as logging
 from oslotest import base
-import six
 import testtools
 
 from oslo_privsep import capabilities
@@ -45,6 +44,20 @@ class TestException(Exception):
     pass
 
 
+def get_fake_context(conf_attrs=None, **context_attrs):
+    conf_attrs = conf_attrs or {}
+    context = mock.NonCallableMock()
+    context.conf.user = 42
+    context.conf.group = 84
+    context.conf.thread_pool_size = 10
+    context.conf.capabilities = [
+        capabilities.CAP_SYS_ADMIN, capabilities.CAP_NET_ADMIN]
+    context.conf.logger_name = 'oslo_privsep.daemon'
+    vars(context).update(context_attrs)
+    vars(context.conf).update(conf_attrs)
+    return context
+
+
 @testctx.context.entrypoint
 def logme(level, msg, exc_info=False):
     # We want to make sure we log everything from the priv side for
@@ -61,8 +74,7 @@ def logme(level, msg, exc_info=False):
 
 class LogRecorder(pylogging.Formatter):
     def __init__(self, logs, *args, **kwargs):
-        if sys.version_info >= (3, 8):
-            kwargs['validate'] = False
+        kwargs['validate'] = False
         super(LogRecorder, self).__init__(*args, **kwargs)
         self.logs = logs
 
@@ -82,15 +94,15 @@ class LogTest(testctx.TestContextTestCase):
             level=logging.INFO))
 
         # These write to the log on the priv side
-        logme(logging.DEBUG, u'test@DEBUG')
-        logme(logging.WARN, u'test@WARN')
+        logme(logging.DEBUG, 'test@DEBUG')
+        logme(logging.WARN, 'test@WARN')
 
         time.sleep(0.1)  # Hack to give logging thread a chance to run
 
         # logger.output is the resulting log on the unpriv side.
         # This should have been filtered based on (unpriv) loglevel.
-        self.assertNotIn(u'test@DEBUG', logger.output)
-        self.assertIn(u'test@WARN', logger.output)
+        self.assertNotIn('test@DEBUG', logger.output)
+        self.assertIn('test@WARN', logger.output)
 
     def test_record_data(self):
         logs = []
@@ -101,19 +113,19 @@ class LogTest(testctx.TestContextTestCase):
             # class/function, not an instance :(
             formatter=functools.partial(LogRecorder, logs)))
 
-        logme(logging.WARN, u'test with exc', exc_info=True)
+        logme(logging.WARN, 'test with exc', exc_info=True)
 
         time.sleep(0.1)  # Hack to give logging thread a chance to run
 
         self.assertEqual(1, len(logs))
 
         record = logs[0]
-        self.assertIn(u'test with exc', record.getMessage())
+        self.assertIn('test with exc', record.getMessage())
         self.assertIsNone(record.exc_info)
-        self.assertIn(u'TestException: with arg', record.exc_text)
+        self.assertIn('TestException: with arg', record.exc_text)
         self.assertEqual('PrivContext(cfg_section=privsep)',
                          record.processName)
-        self.assertIn(u'test_daemon.py', record.exc_text)
+        self.assertIn('test_daemon.py', record.exc_text)
         self.assertEqual(logging.WARN, record.levelno)
         self.assertEqual('logme', record.funcName)
 
@@ -126,7 +138,7 @@ class LogTest(testctx.TestContextTestCase):
             # class/function, not an instance :(
             formatter=functools.partial(LogRecorder, logs)))
 
-        logme(logging.WARN, u'test with exc', exc_info=True)
+        logme(logging.WARN, 'test with exc', exc_info=True)
 
         time.sleep(0.1)  # Hack to give logging thread a chance to run
 
@@ -152,12 +164,7 @@ class DaemonTest(base.BaseTestCase):
     def test_drop_privs(self, mock_dropcaps, mock_keepcaps,
                         mock_setgroups, mock_setgid, mock_setuid):
         channel = mock.NonCallableMock()
-        context = mock.NonCallableMock()
-        context.conf.user = 42
-        context.conf.group = 84
-        context.conf.thread_pool_size = 10
-        context.conf.capabilities = [
-            capabilities.CAP_SYS_ADMIN, capabilities.CAP_NET_ADMIN]
+        context = get_fake_context()
 
         d = daemon.Daemon(channel, context)
         d._drop_privs()
@@ -189,34 +196,62 @@ class WithContextTest(testctx.TestContextTestCase):
 class ClientChannelTestCase(base.BaseTestCase):
 
     DICT = {
-        'string_1': ('tuple_1', six.b('tuple_2')),
-        six.b('byte_1'): ['list_1', 'list_2'],
+        'string_1': ('tuple_1', b'tuple_2'),
+        b'byte_1': ['list_1', 'list_2'],
     }
 
     EXPECTED = {
-        'string_1': ('tuple_1', six.b('tuple_2')),
+        'string_1': ('tuple_1', b'tuple_2'),
         'byte_1': ['list_1', 'list_2'],
     }
 
     def setUp(self):
         super(ClientChannelTestCase, self).setUp()
+        context = get_fake_context()
         with mock.patch.object(comm.ClientChannel, '__init__'), \
                 mock.patch.object(daemon._ClientChannel, 'exchange_ping'):
-            self.client_channel = daemon._ClientChannel(mock.ANY)
+            self.client_channel = daemon._ClientChannel(mock.ANY, context)
 
-    def test_out_of_band_log_message(self):
-        message = [daemon.Message.LOG, self.DICT]
+    @mock.patch.object(daemon.LOG.logger, 'handle')
+    def test_out_of_band_log_message(self, handle_mock):
+        message = [comm.Message.LOG, self.DICT]
+        self.assertEqual(self.client_channel.log, daemon.LOG)
         with mock.patch.object(pylogging, 'makeLogRecord') as mock_make_log, \
                 mock.patch.object(daemon.LOG, 'isEnabledFor',
-                                  return_value=False):
+                                  return_value=True) as mock_enabled:
             self.client_channel.out_of_band(message)
             mock_make_log.assert_called_once_with(self.EXPECTED)
+            handle_mock.assert_called_once_with(mock_make_log.return_value)
+            mock_enabled.assert_called_once_with(
+                mock_make_log.return_value.levelno)
 
     def test_out_of_band_not_log_message(self):
         with mock.patch.object(daemon.LOG, 'warning') as mock_warning:
-            self.client_channel.out_of_band([daemon.Message.PING])
+            self.client_channel.out_of_band([comm.Message.PING])
             mock_warning.assert_called_once()
 
+    @mock.patch.object(daemon.logging, 'getLogger')
+    @mock.patch.object(pylogging, 'makeLogRecord')
+    def test_out_of_band_log_message_context_logger(self, make_log_mock,
+                                                    get_logger_mock):
+        logger_name = 'os_brick.privileged'
+        context = get_fake_context(conf_attrs={'logger_name': logger_name})
+        with mock.patch.object(comm.ClientChannel, '__init__'), \
+                mock.patch.object(daemon._ClientChannel, 'exchange_ping'):
+            channel = daemon._ClientChannel(mock.ANY, context)
+
+        get_logger_mock.assert_called_once_with(logger_name)
+        self.assertEqual(get_logger_mock.return_value, channel.log)
+
+        message = [comm.Message.LOG, self.DICT]
+        channel.out_of_band(message)
+
+        make_log_mock.assert_called_once_with(self.EXPECTED)
+        channel.log.isEnabledFor.assert_called_once_with(
+            make_log_mock.return_value.levelno)
+        channel.log.logger.handle.assert_called_once_with(
+            make_log_mock.return_value)
+
 
 class UnMonkeyPatch(base.BaseTestCase):
 
